@@ -184,7 +184,7 @@ public class MicroformatServlet extends OnlinePublicationServlet {
 
             final HashMap<String, Object> variables = new HashMap<String, Object>();
             final User user = getUser(publication);
-            final Contact userContact = getContact(new PublicationSession(publication), publication.getContext(), user.getContactId());
+            final Contact userContact = getContact(new PublicationSession(publication), publication.getContext());
             
             variables.put(getCollectionName(module), loaded);
             variables.put("publication", publication);
@@ -217,9 +217,9 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         }
     }
 
-    private Contact getContact(final PublicationSession publicationSession, final Context context, final int contactId) throws OXException {
+    private Contact getContact(final PublicationSession publicationSession, final Context context) throws OXException {
         final ContactInterface contactInterface = contacts.getContactInterfaceProvider(FolderObject.SYSTEM_LDAP_FOLDER_ID, context.getContextId()).newContactInterface(publicationSession);
-        final Contact contact = contactInterface.getObjectById(contactId, FolderObject.SYSTEM_LDAP_FOLDER_ID);
+        final Contact contact = contactInterface.getUserById(publicationSession.getUserId(), false);
         return contact;
     }
 
